@@ -3,6 +3,8 @@
 #include "radiostation.h"
 #include "texteditautoresizer.h"
 
+const QString appVersion = "0.1.0";
+
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow)
@@ -259,11 +261,11 @@ void MainWindow::on_stopButton_clicked()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About"),
-                        tr("<h2>Internet Radio Player 0.0.8</h2>"
+                        QString(tr("<h2>Internet Radio Player %1</h2>"
                            "<p>"
                            "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"
                            "<p><a href=\"http://code-tinkering.blogspot.com/\">My personal blog.</a>"
-                           " <a href=\"mailto:ggiovanni88@yahoo.it\">Send me an email.</a>"));
+                           " <a href=\"mailto:ggiovanni88@yahoo.it\">Send me an email.</a>")).arg(appVersion));
 }
 
 void MainWindow::on_addStationButton_clicked()
@@ -610,3 +612,9 @@ void MainWindow::on_lyricsWebViewButton_clicked()
     lyricsWebView->setWindowTitle(windowTitle);
     lyricsWebView->show();
 }
+
+void MainWindow::on_actionSettings_triggered()
+{
+    SettingsDialog dialog;
+    dialog.exec();
+}
