@@ -6,6 +6,7 @@
 #include "stationsdb.h"
 #include "filterlistbydialog.h"
 #include "lyricswebview.h"
+#include "settingsdialog.h"
 
 #include <QBuffer>
 #include <QClipboard>
@@ -70,6 +71,8 @@ private slots:
     void toggleButtonPressed();
     void on_lyricsWebViewButton_clicked();
 
+    void on_actionSettings_triggered();
+
 private:
     Ui::MainWindow *ui;
     QMediaPlayer* mediaPlayer;
